@@ -1,22 +1,19 @@
 package AnyEvent::Handle;
 
-no warnings;
-use strict qw(subs vars);
-
-use AnyEvent ();
-use AnyEvent::Util qw(WSAEWOULDBLOCK);
 use Scalar::Util ();
 use Carp ();
-use Fcntl ();
 use Errno qw(EAGAIN EINTR);
 
+use AnyEvent (); BEGIN { AnyEvent::common_sense }
+use AnyEvent::Util qw(WSAEWOULDBLOCK);
+
 =head1 NAME
 
 AnyEvent::Handle - non-blocking I/O on file handles via AnyEvent
 
 =cut
 
-our $VERSION = 4.83;
+our $VERSION = 4.85;
 
 =head1 SYNOPSIS
 
